@@ -1,5 +1,4 @@
 
-import binascii
 import json
 
 from calendar import timegm
@@ -25,7 +24,8 @@ def encode(claims, key, algorithm=ALGORITHMS.HS256, headers=None, access_token=N
 
     Args:
         claims (dict): A claims set to sign
-        key (str): The key to use for signing the claim set
+        key (str or dict): The key to use for signing the claim set. Can be
+            individual JWK or JWK set.
         algorithm (str, optional): The algorithm to use for signing the
             the claims.  Defaults to HS256.
         headers (dict, optional): A set of headers that will be added to
@@ -67,7 +67,8 @@ def decode(token, key, algorithms=None, options=None, audience=None,
 
     Args:
         token (str): A signed JWS to be verified.
-        key (str): A key to attempt to verify the payload with.
+        key (str or dict): A key to attempt to verify the payload with. Can be
+            individual JWK or JWK set.
         algorithms (str or list): Valid algorithms that should be used to verify the JWS.
         audience (str): The intended audience of the token.  If the "aud" claim is
             included in the claim set, then the audience must be included and must equal
@@ -78,8 +79,7 @@ def decode(token, key, algorithms=None, options=None, audience=None,
         subject (str): The subject of the token.  If the "sub" claim is
             included in the claim set, then the subject must be included and must equal
             the provided claim.
-        access_token (str): An access token returned alongside the id_token during
-            the authorization grant flow. If the "at_hash" claim is included in the
+        access_token (str): An access token string. If the "at_hash" claim is included in the
             claim set, then the access_token must be included, and it must match
             the "at_hash" claim.
         options (dict): A dictionary of options for skipping validation steps.
@@ -169,7 +169,7 @@ def get_unverified_header(token):
     """
     try:
         headers = jws.get_unverified_headers(token)
-    except:
+    except Exception:
         raise JWTError('Error decoding token headers.')
 
     return headers
@@ -207,7 +207,7 @@ def get_unverified_claims(token):
     """
     try:
         claims = jws.get_unverified_claims(token)
-    except:
+    except Exception:
         raise JWTError('Error decoding token claims.')
 
     try:
@@ -385,6 +385,7 @@ def _validate_sub(claims, subject=None):
         if claims.get('sub') != subject:
             raise JWTClaimsError('Invalid subject')
 
+
 def _validate_jti(claims):
     """Validates that the 'jti' claim is valid.
 
@@ -434,7 +435,7 @@ def _validate_at_hash(claims, access_token, algorithm):
     except (TypeError, ValueError):
         msg = 'Unable to calculate at_hash to verify against token claims.'
         raise JWTClaimsError(msg)
-        
+
     if claims['at_hash'] != expected_hash:
         raise JWTClaimsError('at_hash claim does not match access_token.')
 
